MethodChannelNativeCutout class

An implementation of NativeCutoutPlatform that uses method channels.

Inheritance

Constructors

MethodChannelNativeCutout()

Properties

downloadProgress Stream<ModelDownloadProgress>
Download progress events for the Android ML model. Always empty on iOS.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
progressEventChannel EventChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCache() Future<bool>
Clears cached PNG files written by removeBackground when writeToCache was enabled.
override
clearModel() Future<bool>
Requests release of the downloaded Android ML model.
override
downloadModel() Future<bool>
Downloads the ML model on Android. No-op on iOS (model is bundled with the system).
override
isModelAvailable() Future<bool>
Checks if the ML model is available on Android. Always returns true on iOS (model is bundled with the system).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeBackground(String imagePath, {required CutoutOptions options}) Future<CutoutResult>
Removes the background from an image at the given path.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited